@@ -338,7 +338,7 @@ constructTlsPasswordDescription val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data TlsPasswordDescriptionPropertyInfo
 instance AttrInfo TlsPasswordDescriptionPropertyInfo where
-    type AttrAllowedOps TlsPasswordDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps TlsPasswordDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint TlsPasswordDescriptionPropertyInfo = IsTlsPassword
     type AttrSetTypeConstraint TlsPasswordDescriptionPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint TlsPasswordDescriptionPropertyInfo = (~) T.Text
@@ -348,6 +348,7 @@ instance AttrInfo TlsPasswordDescriptionPropertyInfo where
     type AttrOrigin TlsPasswordDescriptionPropertyInfo = TlsPassword
     attrGet = getTlsPasswordDescription
     attrSet = setTlsPasswordDescription
+    attrPut = setTlsPasswordDescription
     attrTransfer _ v = do
         return v
     attrConstruct = constructTlsPasswordDescription
@@ -390,7 +391,7 @@ constructTlsPasswordFlags val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data TlsPasswordFlagsPropertyInfo
 instance AttrInfo TlsPasswordFlagsPropertyInfo where
-    type AttrAllowedOps TlsPasswordFlagsPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps TlsPasswordFlagsPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint TlsPasswordFlagsPropertyInfo = IsTlsPassword
     type AttrSetTypeConstraint TlsPasswordFlagsPropertyInfo = (~) [Gio.Flags.TlsPasswordFlags]
     type AttrTransferTypeConstraint TlsPasswordFlagsPropertyInfo = (~) [Gio.Flags.TlsPasswordFlags]
@@ -400,6 +401,7 @@ instance AttrInfo TlsPasswordFlagsPropertyInfo where
     type AttrOrigin TlsPasswordFlagsPropertyInfo = TlsPassword
     attrGet = getTlsPasswordFlags
     attrSet = setTlsPasswordFlags
+    attrPut = setTlsPasswordFlags
     attrTransfer _ v = do
         return v
     attrConstruct = constructTlsPasswordFlags
@@ -442,7 +444,7 @@ constructTlsPasswordWarning val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data TlsPasswordWarningPropertyInfo
 instance AttrInfo TlsPasswordWarningPropertyInfo where
-    type AttrAllowedOps TlsPasswordWarningPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps TlsPasswordWarningPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint TlsPasswordWarningPropertyInfo = IsTlsPassword
     type AttrSetTypeConstraint TlsPasswordWarningPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint TlsPasswordWarningPropertyInfo = (~) T.Text
@@ -452,6 +454,7 @@ instance AttrInfo TlsPasswordWarningPropertyInfo where
     type AttrOrigin TlsPasswordWarningPropertyInfo = TlsPassword
     attrGet = getTlsPasswordWarning
     attrSet = setTlsPasswordWarning
+    attrPut = setTlsPasswordWarning
     attrTransfer _ v = do
         return v
     attrConstruct = constructTlsPasswordWarning
